==> streamdown-0.6.0.tar.gz: streamdown-0.6.0/tests/table_test.md <==

| **Window Manager** | **Type**        | **License** | **Configuration** | **Features**                                                                                                                          | **Complexity** | **Homepage**                                   |
| :----------------- | :-------------- | :---------- | :---------------- | :------------------------------------------------------------------------------------------------------------------------------------ | :------------- | :--------------------------------------------- |
| **i3**             | Tiling          | GPLv2       | Text file         | Simple, fast, powerful, dynamic tiling, keyboard-focused, excellent documentation, widely used. Supports workspaces.                  | Medium         | [https://i3wm.org/](https://i3wm.org/)        |
| **Awesome**        | Tiling          | GPLv2       | Lua script        | Highly configurable, dynamic tiling, widget-based, Lua scripting for customization, rich ecosystem.  Can be complex to learn.           | High           | [https://awesomewm.org/](https://awesomewm.org/) |
| **Xmonad**         | Tiling          | BSD 3-Clause| Haskell           | Written in Haskell. Dynamic tiling, extremely configurable, mathematically inspired layout algorithms. Steep learning curve.        | Very High      | [https://xmonad.org/](https://xmonad.org/)      |
| **dwm**            | Tiling          | MIT         | C code            | Minimalist, dynamic tiling, extremely lightweight, fast. Configuration requires recompiling the code. Very challenging to customize.  | High          | [https://dwm.suckless.org/](https://dwm.suckless.org/) |
| **bspwm**          | Tiling          | GPLv2       | Text file         | Binary space partitioning tiling, allows for complex layouts, highly customizable. Requires a separate panel/bar (e.g., polybar).      | Medium         | [https://bspwm.org/](https://bspwm.org/)        |
| **Openbox**        | Stacking        | GPLv2       | Text file         | Lightweight, highly configurable stacking manager.  Good for those transitioning from traditional desktop environments.               | Low-Medium     | [https://openbox.org/](https://openbox.org/)    |
| **Fluxbox**        | Stacking        | GPLv2       | Text file         | Derived from Blackbox, lightweight, configurable, focuses on speed and low resource usage.                                         | Low-Medium     | [https://fluxbox.org/](https://fluxbox.org/)    |
| **Window Maker**   | Stacking        | MIT         | Text file         | Inspired by NeXTSTEP, Dock-like application menu, configurable, and lightweight.                                                        | Low-Medium     | [https://www.windowmaker.org/](https://www.windowmaker.org/) |
| **Compiz**         | Stacking/Tiling| GPLv2       | Configuration UI  | Advanced compositing effects, 3D effects, can be configured for tiling.  Can be resource intensive.                                | High           | [https://compiz.sourceforge.net/](https://compiz.sourceforge.net/) |
| **ratpoison**      | Tiling          | MIT         | Text file         | Unique tiling approach, based on text-based control.  Windows are moved around using keyboard commands, mimicking a terminal.       | Medium         | [http://www.ratpoisonwm.org/](http://www.ratpoisonwm.org/) |
| **Herbstluftwm**   | Tiling          | GPLv3       | Text file         | Fractal Tiling, semi-dynamic tiling, focusing on rule-based window placement. Uses a separate bar (e.g., polybar).                   | Medium         | [https://herbstluftwm.org/](https://herbstluftwm.org/) |
| **Qtile**          | Tiling          | GPLv3       | Python            | Written in Python, dynamic tiling, highly configurable, flexible layout control. Good for those familiar with Python.                | Medium-High    | [https://docs.qtile.org/en/latest/](https://docs.qtile.org/en/latest/) |
| **Wayfire**        | Wayland Compositor/WM | GPLv3       | Text file         | A 3D Wayland compositor acting as a window manager. Lightweight and flexible, with support for plugins and animations.               | Medium         | [https://wayfire.org/](https://wayfire.org/) |
| **Hyprland**       | Wayland Compositor/WM | MIT         | Text file         | A dynamic tiling Wayland compositor. Highly configurable, focused on performance, and supports animations and complex effects.    | Medium-High    | [https://hyprland.org/](https://hyprland.org/) |

that's it

==> streamdown-0.16.0.tar.gz: streamdown-0.16.0/tests/table_test.md <==

| **Window Manager** | **Type**        | **License** | **Configuration** | **Features**                                                                                                                          | **Complexity** | **Homepage**                                   |
| :----------------- | :-------------- | :---------- | :---------------- | :------------------------------------------------------------------------------------------------------------------------------------ | :------------- | :--------------------------------------------- |
| **i3**             | Tiling          | GPLv2       | Text file         | Simple, fast, powerful, dynamic tiling, keyboard-focused, excellent documentation, widely used. Supports workspaces.                  | Medium         | [https://i3wm.org/](https://i3wm.org/)        |
| **Awesome**        | Tiling          | GPLv2       | Lua script        | Highly configurable, dynamic tiling, widget-based, Lua scripting for customization, rich ecosystem.  Can be complex to learn.           | High           | [https://awesomewm.org/](https://awesomewm.org/) |
| **Xmonad**         | Tiling          | BSD 3-Clause| Haskell           | Written in Haskell. Dynamic tiling, extremely configurable, mathematically inspired layout algorithms. Steep learning curve.        | Very High      | [https://xmonad.org/](https://xmonad.org/)      |
| **dwm**            | Tiling          | MIT         | C code            | Minimalist, dynamic tiling, extremely lightweight, fast. Configuration requires recompiling the code. Very challenging to customize.  | High          | [https://dwm.suckless.org/](https://dwm.suckless.org/) |
| **bspwm**          | `Tiling`          | GPLv2       | Text file         | Binary space partitioning tiling, allows for complex layouts, highly customizable. Requires a separate panel/bar (e.g., polybar).      | Medium         | [https://bspwm.org/](https://bspwm.org/)        |
| **Openbox**        | Stacking        | GPLv2       | Text file         | Lightweight, highly configurable stacking manager.  Good for those transitioning from traditional desktop environments.               | Low-Medium     | [https://openbox.org/](https://openbox.org/)    |
| **Fluxbox**        | Stacking        | GPLv2       | Text file         | Derived from Blackbox, lightweight, configurable, focuses on speed and low resource usage.                                         | Low-Medium     | [https://fluxbox.org/](https://fluxbox.org/)    |
| **Window Maker**   | Stacking        | MIT         | Text file         | Inspired by NeXTSTEP, Dock-like application menu, configurable, and lightweight.                                                        | Low-Medium     | [https://www.windowmaker.org/](https://www.windowmaker.org/) |
| **Compiz**         | Stacking/Tiling| GPLv2       | Configuration UI  | Advanced compositing effects, 3D effects, can be configured for tiling.  Can be resource intensive.                                | High           | [https://compiz.sourceforge.net/](https://compiz.sourceforge.net/) |
| **ratpoison**      | Tiling          | MIT         | Text file         | Unique tiling approach, based on text-based control.  Windows are moved around using keyboard commands, mimicking a terminal.       | Medium         | [http://www.ratpoisonwm.org/](http://www.ratpoisonwm.org/) |
| **Herbstluftwm**   | Tiling          | GPLv3       | Text file         | Fractal Tiling, semi-dynamic tiling, focusing on rule-based window placement. Uses a separate bar (e.g., polybar).                   | Medium         | [https://herbstluftwm.org/](https://herbstluftwm.org/) |
| **Qtile**          | Tiling          | GPLv3       | Python            | Written in Python, dynamic tiling, highly configurable, flexible layout control. Good for those familiar with Python.                | Medium-High    | [https://docs.qtile.org/en/latest/](https://docs.qtile.org/en/latest/) |
| **Wayfire**        | Wayland Compositor/WM | GPLv3       | Text file         | A 3D Wayland compositor acting as a window manager. Lightweight and flexible, with support for plugins and animations.               | Medium         | [https://wayfire.org/](https://wayfire.org/) |
| **Hyprland**       | Wayland Compositor/WM | MIT         | Text file         | A dynamic tiling Wayland compositor. Highly configurable, focused on performance, and supports animations and complex effects.    | Medium-High    | [https://hyprland.org/](https://hyprland.org/) |

that's it

blah blah
